==> news_1.0.jar: edu/northwestern/news/anomaly/AlarmRecord.java <==
/**
 * NEWS Project
 *
 * File:         AlarmRecord.java
 * RCS:          $Id: AlarmRecord.java,v 1.2 2008/10/24 21:11:55 drc915 Exp $
 * Description:  AlarmRecord class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 29, 2008 at 10:45:31 AM
 * Language:     Java
 * Package:      edu.northwestern.news.ui
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2008, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.news.anomaly;


public class AlarmRecord {
	public AlarmRecord(String region, AnomalyRecord r, int count) {
		this.record = r;
		this.region = region;
		this.count = count;
	}
	public AnomalyRecord record;
	public int count;
	public String region;	
	public boolean isAlarm =false;
}

==> news_2.0.1.jar: edu/northwestern/news/anomaly/AlarmRecord.java <==
/**
 * NEWS Project
 *
 * File:         AlarmRecord.java
 * RCS:          $Id: AlarmRecord.java,v 1.3 2009/10/21 13:15:25 drc915 Exp $
 * Description:  AlarmRecord class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 29, 2008 at 10:45:31 AM
 * Language:     Java
 * Package:      edu.northwestern.news.ui
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2008, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.news.anomaly;


public class AlarmRecord {
	public AlarmRecord(String region, AnomalyRecord r, int count, 
			double ratio) {
		this.record = r;
		this.region = region;
		this.count = count;
		this.likelihoodRatio = ratio;
	}
	public AnomalyRecord record;
	public int count;
	public String region;	
	public boolean isAlarm =false;
	public double likelihoodRatio = -1;
}
